bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOMoments.__init__
=====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOMoments.__init__